@@ -2,7 +2,7 @@ import pypstruct, json
 import ccmap as core
 from .threads import run as computeMany
 from .ctype import isVector3F, isEvenEulerTranslationVectorList
-from .plugins import enrich_map
+from .plugins import enrich_map, assert_enrich_valid
 
 def setThreadParameters(**kwargs):
     """ Set parameters required for parrallel computing """
@@ -163,8 +163,10 @@ def contactMap(proteinA, proteinB=None, enrich=False, **kwargs):
     except:
         raise TypeError("First to pameters must have same type string or list")
 
-
     lcMap = isinstance(proteinA, list)
+
+    assert_enrich_valid(proteinA, proteinB, enrich, **kwargs)
+
     pdbREC = pypstruct.parseFilePDB(proteinA)\
              if not lcMap\
              else [ pypstruct.parseFilePDB(_).atomDictorize\
